==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/content/decoration/MetalScaffoldingBlock.java <==
package com.zurrtum.create.content.decoration;

import com.zurrtum.create.AllShapes;
import com.zurrtum.create.content.equipment.wrench.IWrenchable;
import com.zurrtum.create.foundation.block.ScaffoldingControlBlock;
import net.minecraft.class_10225;
import net.minecraft.class_1922;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3726;
import net.minecraft.class_3736;
import net.minecraft.class_4538;
import net.minecraft.class_5819;

public class MetalScaffoldingBlock extends class_3736 implements IWrenchable, ScaffoldingControlBlock {

    public MetalScaffoldingBlock(class_2251 pProperties) {
        super(pProperties);
    }

    @Override
    public void method_9588(class_2680 pState, class_3218 pLevel, class_2338 pPos, class_5819 pRand) {
    }

    @Override
    public boolean method_9558(class_2680 pState, class_4538 pLevel, class_2338 pPos) {
        return true;
    }

    @Override
    public class_265 method_9549(class_2680 pState, class_1922 pLevel, class_2338 pPos, class_3726 pContext) {
        if (pState.method_11654(field_16547))
            return AllShapes.SCAFFOLD_HALF;
        return super.method_9549(pState, pLevel, pPos, pContext);
    }

    @Override
    public class_265 method_9530(class_2680 pState, class_1922 pLevel, class_2338 pPos, class_3726 pContext) {
        if (pState.method_11654(field_16547))
            return AllShapes.SCAFFOLD_HALF;
        if (!pContext.method_17785(pState.method_26204().method_8389()))
            return AllShapes.SCAFFOLD_FULL;
        return class_259.method_1077();
    }

    @Override
    public class_265 method_9584(class_2680 pState, class_1922 pLevel, class_2338 pPos) {
        return class_259.method_1077();
    }

    @Override
    public class_2680 method_9559(
        class_2680 pState,
        class_4538 pLevel,
        class_10225 tickView,
        class_2338 pCurrentPos,
        class_2350 pFacing,
        class_2338 pFacingPos,
        class_2680 pFacingState,
        class_5819 random
    ) {
        super.method_9559(pState, pLevel, tickView, pCurrentPos, pFacing, pFacingPos, pFacingState, random);
        class_2680 stateBelow = pLevel.method_8320(pCurrentPos.method_10074());
        return pFacing == class_2350.field_11033 ? pState.method_11657(
            field_16547,
            !stateBelow.method_27852(this) && !stateBelow.method_26206(pLevel, pCurrentPos.method_10074(), class_2350.field_11036)
        ) : pState;
    }

    //TODO
    //    @Override
    //    public boolean supportsExternalFaceHiding(BlockState state) {
    //        return true;
    //    }

    //TODO
    //    @Override
    //    public boolean hidesNeighborFace(BlockView level, BlockPos pos, BlockState state, BlockState neighborState, Direction dir) {
    //        if (!(neighborState.getBlock() instanceof MetalScaffoldingBlock))
    //            return false;
    //        if (!neighborState.get(BOTTOM) && state.get(BOTTOM))
    //            return false;
    //        return dir.getAxis() != Axis.Y;
    //    }

}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/decoration/MetalScaffoldingBlock.java <==
package com.zurrtum.create.content.decoration;

import com.zurrtum.create.AllShapes;
import com.zurrtum.create.content.equipment.wrench.IWrenchable;
import com.zurrtum.create.foundation.block.ScaffoldingControlBlock;
import net.minecraft.class_10225;
import net.minecraft.class_1802;
import net.minecraft.class_1922;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3726;
import net.minecraft.class_3736;
import net.minecraft.class_4538;
import net.minecraft.class_5819;

public class MetalScaffoldingBlock extends class_3736 implements IWrenchable, ScaffoldingControlBlock {

    public MetalScaffoldingBlock(class_2251 pProperties) {
        super(pProperties);
    }

    @Override
    public void method_9588(class_2680 pState, class_3218 pLevel, class_2338 pPos, class_5819 pRand) {
    }

    @Override
    public boolean method_9558(class_2680 pState, class_4538 pLevel, class_2338 pPos) {
        return true;
    }

    @Override
    public class_265 method_9549(class_2680 pState, class_1922 pLevel, class_2338 pPos, class_3726 pContext) {
        if (pState.method_11654(field_16547))
            return AllShapes.SCAFFOLD_HALF;
        return super.method_9549(pState, pLevel, pPos, pContext);
    }

    @Override
    public class_265 method_9530(class_2680 pState, class_1922 pLevel, class_2338 pPos, class_3726 pContext) {
        if (pState.method_11654(field_16547))
            return AllShapes.SCAFFOLD_HALF;
        if (pContext.method_17785(class_1802.field_8162) || !pContext.method_17785(pState.method_26204().method_8389()))
            return AllShapes.SCAFFOLD_FULL;
        return class_259.method_1077();
    }

    @Override
    public class_265 method_9584(class_2680 pState, class_1922 pLevel, class_2338 pPos) {
        return class_259.method_1077();
    }

    @Override
    public class_2680 method_9559(
        class_2680 pState,
        class_4538 pLevel,
        class_10225 tickView,
        class_2338 pCurrentPos,
        class_2350 pFacing,
        class_2338 pFacingPos,
        class_2680 pFacingState,
        class_5819 random
    ) {
        super.method_9559(pState, pLevel, tickView, pCurrentPos, pFacing, pFacingPos, pFacingState, random);
        class_2680 stateBelow = pLevel.method_8320(pCurrentPos.method_10074());
        return pFacing == class_2350.field_11033 ? pState.method_11657(
            field_16547,
            !stateBelow.method_27852(this) && !stateBelow.method_26206(pLevel, pCurrentPos.method_10074(), class_2350.field_11036)
        ) : pState;
    }

    //TODO
    //    @Override
    //    public boolean supportsExternalFaceHiding(BlockState state) {
    //        return true;
    //    }

    //TODO
    //    @Override
    //    public boolean hidesNeighborFace(BlockView level, BlockPos pos, BlockState state, BlockState neighborState, Direction dir) {
    //        if (!(neighborState.getBlock() instanceof MetalScaffoldingBlock))
    //            return false;
    //        if (!neighborState.get(BOTTOM) && state.get(BOTTOM))
    //            return false;
    //        return dir.getAxis() != Axis.Y;
    //    }

}
